@@ -9,46 +9,30 @@ __all__ = [
     "Function",
     "FunctionModel",
     "FunctionVectorized",
-    "Marginal",
-    "MarginalNamed",
-    "MarginalGKDE",
     "Model",
     "NaN",
 ]
 
-from abc import ABC, abstractmethod
 import copy
-
-from numpy import (
-    ones,
-    zeros,
-    triu_indices,
-    eye,
-    array,
-    Inf,
-    NaN,
-    sqrt,
-    dot,
-    diag,
-    isfinite,
-)
+import networkx as nx
+import warnings
+from grama import pipe, valid_dist, param_dist
+from .tools import tran_outer
+from abc import ABC, abstractmethod
+from itertools import chain
+from numpy import ones, zeros, triu_indices, eye, array, Inf, NaN, sqrt, \
+    dot, diag, isfinite
 from numpy import min as npmin
 from numpy import max as npmax
+from numpy.linalg import cholesky
 from numpy.random import random, multivariate_normal
 from numpy.random import seed as set_seed
+from pandas import DataFrame, concat
 from scipy.linalg import det, LinAlgError, solve
 from scipy.optimize import root_scalar
 from scipy.stats import norm, gaussian_kde
-from pandas import DataFrame, concat
-
-import grama as gr
-from grama import pipe, valid_dist, param_dist
-
-from itertools import chain
-from numpy.linalg import cholesky
 from toolz import curry
-import warnings
-import networkx as nx
+
 
 ## Package settings
 RUNTIME_LOWER = 1  # Cutoff threshold for runtime messages
@@ -272,206 +256,30 @@ class Domain:
     def get_bound(self, var):
         if var in self.bounds.keys():
             return (self.bounds[var][0], self.bounds[var][1])
-        else:
-            return (-Inf, +Inf)
+        return (-Inf, +Inf)
 
     def get_width(self, var):
         if var in self.bounds.keys():
             return self.bounds[var][1] - self.bounds[var][0]
-        else:
-            return +Inf
+        return +Inf
 
     def get_nominal(self, var):
         if var in self.bounds.keys():
             if isfinite(self.bounds[var][0]):
                 if isfinite(self.bounds[var][1]):
                     return 0.5 * (self.bounds[var][1] + self.bounds[var][0])
-                else:
-                    return self.bounds[var][0]
-            else:
-                if isfinite(self.bounds[var][1]):
-                    return self.bounds[var][1]
-                else:
-                    return NaN
-
-        else:
+                return self.bounds[var][0]
+            if isfinite(self.bounds[var][1]):
+                return self.bounds[var][1]
             return NaN
+        return NaN
 
     def bound_summary(self, var):
         if var in self.bounds.keys():
             return "{0:}: [{1:}, {2:}]".format(
                 var, self.bounds[var][0], self.bounds[var][1],
             )
-        else:
-            return "{0:}: (unbounded)".format(var)
-
-
-# Marginal parent class
-class Marginal(ABC):
-    """Parent class for marginal distributions
-    """
-
-    def __init__(self, sign=0):
-        self.sign = sign
-
-    @abstractmethod
-    def copy(self):
-        pass
-
-    ## Fitting function
-    @abstractmethod
-    def fit(self, data):
-        pass
-
-    ## Likelihood function
-    @abstractmethod
-    def l(self, x):
-        pass
-
-    ## Cumulative density function
-    @abstractmethod
-    def p(self, x):
-        pass
-
-    ## Quantile function
-    @abstractmethod
-    def q(self, p):
-        pass
-
-    ## Summary
-    @abstractmethod
-    def summary(self):
-        pass
-
-
-## Named marginal class
-class MarginalNamed(Marginal):
-    """Marginal using a named distribution from gr.valid_dist"""
-
-    def __init__(self, d_name=None, d_param=None, **kw):
-        super().__init__(**kw)
-
-        self.d_name = d_name
-        self.d_param = d_param
-
-    def copy(self):
-        new_marginal = MarginalNamed(
-            sign=self.sign, d_name=self.d_name, d_param=copy.deepcopy(self.d_param)
-        )
-
-        return new_marginal
-
-    ## Fitting function
-    def fit(self, data):
-        param = valid_dist[self.d_name].fit(data)
-        self.d_param = dict(zip(param_dist[dist], param))
-
-    ## Likelihood function
-    def l(self, x):
-        return valid_dist[self.d_name].pdf(x, **self.d_param)
-
-    ## Cumulative density function
-    def p(self, x):
-        return valid_dist[self.d_name].cdf(x, **self.d_param)
-
-    ## Quantile function
-    def q(self, p):
-        return valid_dist[self.d_name].ppf(p, **self.d_param)
-
-    ## Summary
-    def summary(self):
-        return "({0:+}) {1:}, {2:}".format(self.sign, self.d_name, self.d_param)
-
-
-## Gaussian KDE marginal class
-class MarginalGKDE(Marginal):
-    """Marginal using scipy.stats.gaussian_kde"""
-
-    def __init__(self, kde, atol=1e-6, **kw):
-        super().__init__(**kw)
-
-        self.kde = kde
-        self.atol = atol
-        self._set_bracket()
-
-    def copy(self):
-        new_marginal = MarginalGKDE(kde=copy.deepcopy(self.kde), atol=self.atol,)
-
-        return new_marginal
-
-    def _set_bracket(self):
-        ## Calibrate the quantile brackets based on desired accuracy
-        bracket = [npmin(self.kde.dataset), npmax(self.kde.dataset)]
-
-        sol_lo = root_scalar(
-            lambda x: self.atol - self.p(x),
-            x0=bracket[0],
-            x1=bracket[1],
-            method="secant",
-        )
-        sol_hi = root_scalar(
-            lambda x: 1 - self.atol - self.p(x),
-            x0=bracket[0],
-            x1=bracket[1],
-            method="secant",
-        )
-
-        self.bracket = [sol_lo.root, sol_hi.root]
-
-    ## Fitting function
-    def fit(self, data):
-        self.kde = gaussian_kde(data)
-        self._set_bracket()
-
-    ## Likelihood function
-    def l(self, x):
-        return self.kde.pdf(x)
-
-    ## Cumulative density function
-    def p(self, x):
-        try:
-            return array([self.kde.integrate_box_1d(-Inf, v) for v in x])
-        except TypeError:
-            return self.kde.integrate_box_1d(-Inf, x)
-
-    ## Quantile function
-    def q(self, p):
-        p_bnd = self.p(self.bracket)
-
-        ## Create scalar solver
-        def qscalar(val):
-            if val <= p_bnd[0]:
-                return self.bracket[0]
-            elif val >= p_bnd[1]:
-                return self.bracket[1]
-            else:
-                sol = root_scalar(
-                    lambda x: val - self.p(x),
-                    bracket=self.bracket,
-                    method="bisect",
-                    xtol=self.atol,
-                )
-                return sol.root
-
-        ## Iterate over all given values
-        try:
-            res = zeros(len(p))
-            for i in range(len(p)):
-                res[i] = qscalar(p[i])
-        except TypeError:
-            res = qscalar(p)
-
-        return res
-
-    ## Summary
-    def summary(self):
-        p_bnd = self.p(self.bracket)
-
-        return "({0:+}) gaussian KDE, n={1:2.1f}/{2:}, f={3:2.1e}, ".format(
-            self.sign, self.kde.neff, self.kde.dataset.shape[1], self.kde.factor
-        ) + "b=[{0:2.1e}, {1:2.1e}], a={2:1.0e}".format(
-            self.bracket[0], self.bracket[1], self.atol
-        )
+        return "{0:}: (unbounded)".format(var)
 
 
 ## Copula base class
@@ -914,8 +722,7 @@ class Density:
     def summary_copula(self):
         if not (self.copula is None):
             return self.copula.summary()
-        else:
-            return None
+        return None
 
 
 # Model parent class
@@ -1049,8 +856,7 @@ class Model:
 
         if runtime < RUNTIME_LOWER:
             return None
-        else:
-            return "Estimated runtime: {0:3.4f} sec".format(runtime)
+        return "Estimated runtime: {0:3.4f} sec".format(runtime)
 
     def det_nom(self):
         """Return nominal conditions for deterministic variables
@@ -1128,7 +934,7 @@ class Model:
             return df_det
 
         ## Outer product if both det and rand exist
-        return gr.tran_outer(df_rand, df_det)
+        return tran_outer(df_rand, df_det)
 
     ## Sample transforms
     # --------------------------------------------------
@@ -1287,28 +1093,51 @@ class Model:
 
     ## Model information
     # -------------------------
+    def string_rep(self):
+        l = [
+            "model: {}".format(self.name),
+            "",
+            "  inputs:",
+            "    var_det:",
+            "".join([
+                "      {}\n".format(self.domain.bound_summary(var_det))
+                for var_det in self.var_det
+            ]),
+            "    var_rand:",
+        ]
+
+        try:
+            l = l + [
+                "".join([
+                    "      {}\n".format(self.density.summary_marginal(var_rand))
+                    for var_rand in self.density.marginals.keys()
+                ]),
+            ]
+        except AttributeError:
+            l = l + ["\n"]
+
+        l = l + [
+            "    copula:",
+            "      {}\n".format(self.density.summary_copula()),
+            "  functions:",
+            "".join([
+                "      {}\n".format(function.summary())
+                for function in self.functions
+            ])
+        ]
+
+        return "\n".join(l)
+
+    def __str__(self):
+        return self.string_rep()
+
+    def __repr__(self):
+        return self.string_rep()
+
     def printpretty(self):
         """Formatted print of model attributes
         """
-        print("model: {}".format(self.name))
-        print("")
-        print("  inputs:")
-        print("    var_det:")
-        for var_det in self.var_det:
-            print("      {}".format(self.domain.bound_summary(var_det)))
-
-        print("    var_rand:")
-        try:
-            for key, marginal in self.density.marginals.items():
-                print("      {}".format(self.density.summary_marginal(key)))
-        except AttributeError:
-            pass
-        print("    copula:")
-        print("        {}".format(self.density.summary_copula()))
-
-        print("  functions:")
-        for function in self.functions:
-            print("    {}".format(function.summary()))
+        print(self.string_rep())
 
     def make_dag(self, expand=set()):
         """Generate a DAG for the model
