@@ -38,11 +38,11 @@ Datasets:
     df_ruff: Metal data from Ruff (1984). Columns:
         part: Part identifier
 
-        TYS: Tensile Yield Stress (ksi), averaged over two coupons
+        TYS: Tensile Yield Stress (ksi)
 
-        TUS: Tensile Ultimate Stress (ksi), averaged over two coupons
+        TUS: Tensile Ultimate Stress (ksi)
 
-        thickness: Coupon thickness (in)
+        thickness: Part thickness (in)
 
     df_trajectory_full: Simulated trajectory data. Columns:
 
