@@ -5,16 +5,17 @@ __all__ = [
     "ev_min",
 ]
 
-from grama import add_pipe, pipe, custom_formatwarning, df_make
-from grama import eval_df, eval_nominal, eval_monte_carlo
-from grama import comp_marginals, comp_copula_independence
-from grama import tran_outer
+from grama import add_pipe, pipe, custom_formatwarning, df_make, \
+    eval_df, eval_nominal, eval_monte_carlo, comp_marginals, \
+    comp_copula_independence, tran_outer
 from numpy import Inf, isfinite
 from numpy.random import seed as setseed
 from pandas import DataFrame, concat
+from pathos.multiprocessing import ProcessingPool as Pool
 from scipy.optimize import minimize
 from toolz import curry
 
+
 ## Nonlinear least squares
 # --------------------------------------------------
 @curry
@@ -30,6 +31,7 @@ def eval_nls(
     gtol=1e-5,
     n_maxiter=100,
     n_restart=1,
+    n_process=1,
     method="L-BFGS-B",
     seed=None,
     verbose=True,
@@ -184,7 +186,7 @@ def eval_nls(
 
     ## Iterate over initial guesses
     df_res = DataFrame()
-    for i in range(n_restart):
+    def fun_mp(i):
         x0 = df_init[var_fit].iloc[i].values
         ## Build evaluator
         def objective(x):
@@ -214,7 +216,6 @@ def eval_nls(
             bounds=bounds,
         )
 
-        ## Package results
         df_tmp = df_make(
             **dict(zip(var_fit, res.x)),
             **dict(zip(map(lambda s: s + "_0", var_fit), x0)),
@@ -223,14 +224,20 @@ def eval_nls(
         df_tmp["message"] = [res.message]
         df_tmp["n_iter"] = [res.nit]
         df_tmp["mse"] = [res.fun]
+        return df_tmp
 
-        df_res = concat((df_res, df_tmp,), axis=0,).reset_index(drop=True)
+    num_process = n_process
+    if num_process > n_restart:
+        num_process = n_restart
+
+    pool = Pool(processes = num_process)
+    mp_out = pool.map(fun_mp, range(n_restart))
+    df_res = concat(mp_out, axis=0,).reset_index(drop=True)
 
     ## Post-process
     if append:
         return df_res
-    else:
-        return df_res[var_fit]
+    return df_res[var_fit]
 
 
 ev_nls = add_pipe(eval_nls)
@@ -262,9 +269,9 @@ def eval_min(
         model (gr.Model): Model to analyze. All model variables must be
             deterministic.
         out_min (str): Output to use as minimization objective.
-        out_geq (None OR list of str): Outputs to use as geq constraints; var >= 0
-        out_leq (None OR list of str): Outputs to use as leq constraints; var <= 0
-        out_eq (None OR list of str): Outputs to use as equality constraints; var == 0
+        out_geq (None OR list of str): Outputs to use as geq constraints; out >= 0
+        out_leq (None OR list of str): Outputs to use as leq constraints; out <= 0
+        out_eq (None OR list of str): Outputs to use as equality constraints; out == 0
 
         method (str): Optimization method; see the documentation for
             scipy.optimize.minimize for options.
