@@ -11,7 +11,6 @@ except ModuleNotFoundError:
     raise ModuleNotFoundError("module lolopy not found")
 
 import grama as gr
-
 from grama import add_pipe, pipe
 from numpy import stack
 from numpy.random import seed as set_seed
@@ -19,6 +18,7 @@ from pandas import DataFrame
 from toolz import curry
 from warnings import filterwarnings
 
+
 ## Helper functions and classes
 # --------------------------------------------------
 class FunctionRFR(gr.Function):
@@ -35,9 +35,9 @@ class FunctionRFR(gr.Function):
 
         self.return_std = return_std
         if return_std:
-            self.out = out + list(map(lambda s: s + "_sd", out))
+            self.out = list(map(lambda s: s + "_mean", out)) + list(map(lambda s: s + "_sd", out))
         else:
-            self.out = out
+            self.out = list(map(lambda s: s + "_mean", out))
 
     def eval(self, df):
         ## Check invariant; model inputs must be subset of df columns
