@@ -4,40 +4,35 @@ __all__ = [
     "custom_formatwarning",
     "df_equal",
     "df_make",
-    "marg_gkde",
-    "marg_named",
     "param_dist",
     "pipe",
     "valid_dist",
+    "tran_outer",
+    "tf_outer",
 ]
 
-import grama as gr
-import pandas as pd
 import warnings
-
 from functools import wraps
-from numbers import Integral
 from inspect import signature
+from numbers import Integral
+from pandas import DataFrame, concat
+from pandas.testing import assert_frame_equal
+from scipy.stats import alpha, anglit, arcsine, argus, beta, betaprime, \
+    bradford, burr, burr12, cauchy, chi, chi2, cosine, crystalball, dgamma, \
+    dweibull, erlang, expon, exponnorm, exponweib, exponpow, f, fatiguelife, \
+    fisk, foldcauchy, foldnorm, gaussian_kde, genlogistic, gennorm, genpareto, \
+    genexpon, genextreme, gausshyper, gamma, gengamma, genhalflogistic, \
+    gilbrat, gompertz, gumbel_r, gumbel_l, halfcauchy, halflogistic, \
+    halfnorm, halfgennorm, hypsecant, invgamma, invgauss, invweibull, \
+    johnsonsb, johnsonsu, kappa4, kappa3, ksone, kstwobign, laplace, levy, \
+    levy_l, levy_stable, logistic, loggamma, loglaplace, lognorm, lomax, \
+    maxwell, mielke, moyal, nakagami, ncx2, ncf, nct, norm, norminvgauss, \
+    pareto, pearson3, powerlaw, powerlognorm, powernorm, rdist, rayleigh, \
+    rice, recipinvgauss, skewnorm, t, trapz, triang, truncexpon, truncnorm, \
+    tukeylambda, uniform, vonmises, vonmises_line, wald, weibull_min, \
+    weibull_max, wrapcauchy
+from toolz import curry
 
-from scipy.stats import gaussian_kde
-
-from scipy.stats import alpha, anglit, arcsine, argus, beta, betaprime
-from scipy.stats import bradford, burr, burr12, cauchy, chi, chi2, cosine
-from scipy.stats import crystalball, dgamma, dweibull, erlang, expon, exponnorm
-from scipy.stats import exponweib, exponpow, f, fatiguelife, fisk, foldcauchy
-from scipy.stats import foldnorm, genlogistic, gennorm
-from scipy.stats import genpareto, genexpon, genextreme, gausshyper, gamma
-from scipy.stats import gengamma, genhalflogistic, gilbrat, gompertz
-from scipy.stats import gumbel_r, gumbel_l, halfcauchy, halflogistic, halfnorm
-from scipy.stats import halfgennorm, hypsecant, invgamma, invgauss, invweibull
-from scipy.stats import johnsonsb, johnsonsu, kappa4, kappa3, ksone, kstwobign
-from scipy.stats import laplace, levy, levy_l, levy_stable, logistic, loggamma
-from scipy.stats import loglaplace, lognorm, lomax, maxwell, mielke, moyal, nakagami
-from scipy.stats import ncx2, ncf, nct, norm, norminvgauss, pareto, pearson3
-from scipy.stats import powerlaw, powerlognorm, powernorm, rdist, rayleigh
-from scipy.stats import rice, recipinvgauss, skewnorm, t, trapz, triang, truncexpon
-from scipy.stats import truncnorm, tukeylambda, uniform, vonmises, vonmises_line
-from scipy.stats import wald, weibull_min, weibull_max, wrapcauchy
 
 ## Scipy metadata
 valid_dist = {
@@ -243,6 +238,7 @@ param_dist = {
     "wrapcauchy": ["c", "loc", "scale"],
 }
 
+
 ## Core helper functions
 ##################################################
 ## Metadata copy
@@ -282,7 +278,7 @@ class pipe(object):
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            if isinstance(other, pd.DataFrame):
+            if isinstance(other, DataFrame):
                 other_copy = copy_meta(other, other_copy)
 
         result = self.function(other_copy)
@@ -308,9 +304,10 @@ def add_pipe(fun):
     class NewPipe(pipe):
         __name__ = fun.__name__
         __doc__ = (
-            "Pipe-enabled version of {}\n".format(fun.__name__)
-            + "Inherited Signature: {}\n".format(signature(fun))
-            + fun.__doc__
+            fun.__doc__
+            #"Pipe-enabled version of {}\n".format(fun)
+            #+ "Inherited Signature: {}\n".format(signature(fun))
+            #+ fun.__doc__
         )
 
     return NewPipe(fun)
@@ -364,7 +361,7 @@ def df_make(**kwargs):
         raise ValueError("Column lengths must be identical or one.")
 
     ## Construct dataframe
-    df_res = pd.DataFrame()
+    df_res = DataFrame()
     for key in kwargs.keys():
         try:
             if len(kwargs[key]) > 1:
@@ -398,7 +395,7 @@ def df_equal(df1, df2, close=False, precision=3):
 
     if close:
         try:
-            pd.testing.assert_frame_equal(
+            assert_frame_equal(
                 df1[df2.columns],
                 df2,
                 check_dtype=False,
@@ -412,93 +409,49 @@ def df_equal(df1, df2, close=False, precision=3):
         return df1[df2.columns].equals(df2)
 
 
-## Fit a named scipy.stats distribution
-def marg_named(data, dist, name=True, sign=None):
-    r"""Fit scipy.stats continuous distirbution
-
-    Fits a named scipy.stats continuous distribution. Intended to be used to
-    define a marginal distribution from data.
-
-    Args:
-        data (iterable): Data for fit
-        dist (str): Distribution to fit
-        name (bool): Include distribution name?
-        sign (bool): Include sign? (Optional)
-
-    Returns:
-        dict: Distribution parameters organized by keyword
-
-    Examples:
-
-        >>> import grama as gr
-        >>> from grama.data import df_stang
-        >>>     gr.cp_marginals(
-        >>>         E=gr.marg_named(df_stang.E, "norm"),
-        >>>         mu=gr.marg_named(df_stang.mu, "beta")
-        >>>     )
-        >>> md.printpretty()
-
-    """
-    ## Catch case where user provides entire DataFrame
-    if isinstance(data, pd.DataFrame):
-        raise ValueError("`data` argument must be a single column; try data.var")
-
-    ## Fit the distribution
-    with warnings.catch_warnings():
-        warnings.simplefilter("ignore")
-        param = valid_dist[dist].fit(data)
-
-    param = dict(zip(param_dist[dist], param))
-
-    if sign is not None:
-        if not (sign in [-1, 0, +1]):
-            raise ValueError("Invalid `sign`")
-    else:
-        sign = 0
-
-    return gr.MarginalNamed(sign=sign, d_name=dist, d_param=param)
-
-
-## Fit a gaussian kernel density estimate (KDE) to data
-def marg_gkde(data, sign=None):
-    r"""Fit a gaussian KDE to data
-
-    Fits a gaussian kernel density estimate (KDE) to data.
-
-    Args:
-        data (iterable): Data for fit
-        sign (bool): Include sign? (Optional)
-
-    Returns:
-        gr.MarginalGKDE: Marginal distribution
-
-    Examples:
-
-        >>> import grama as gr
-        >>> from grama.data import df_stang
-        >>> md = gr.Model("Marginal Example") >> \
-        >>>     gr.cp_marginals(
-        >>>         E=gr.marg_gkde(df_stang.E),
-        >>>         mu=gr.marg_gkde(df_stang.mu)
-        >>>     )
-        >>> md.printpretty()
-
-    """
-    ## Catch case where user provides entire DataFrame
-    if isinstance(data, pd.DataFrame):
-        raise ValueError("`data` argument must be a single column; try data.var")
-
-    kde = gaussian_kde(data)
-    if sign is not None:
-        if not (sign in [-1, 0, +1]):
-            raise ValueError("Invalid `sign`")
-    else:
-        sign = 0
-
-    return gr.MarginalGKDE(kde, sign=sign)
-
-
 ## Monkey-patched warning fcn
 def custom_formatwarning(msg, *args, **kwargs):
     # ignore everything except the message
     return "Warning: " + str(msg) + "\n"
+
+
+## DataFrame outer product
+# --------------------------------------------------
+@curry
+def tran_outer(df, df_outer):
+    r"""Outer merge
+
+    Perform an outer-merge on two dataframes.
+
+    Args:
+        df (DataFrame): Data to merge
+        df_outer (DataFrame): Data to merge; outer
+
+    Returns:
+        DataFrame: Merged data
+
+    Examples:
+        >>> import grama as gr
+        >>> import pandas as pd
+        >>> df = pd.DataFrame(dict(x=[1,2]))
+        >>> df_outer = pd.DataFrame(dict(y=[3,4]))
+        >>> df_res = gr.tran_outer(df, df_outer)
+        >>> df_res
+        >>>    x  y
+        >>> 0  1  3
+        >>> 1  2  3
+        >>> 2  1  4
+        >>> 3  2  4
+
+    """
+    n_rows = df.shape[0]
+    list_df = []
+
+    for ind in range(df_outer.shape[0]):
+        df_rep = concat([df_outer.iloc[[ind]]] * n_rows, ignore_index=True)
+        list_df.append(concat((df, df_rep), axis=1))
+
+    return concat(list_df, ignore_index=True)
+
+
+tf_outer = add_pipe(tran_outer)
